@@ -1,6 +1,6 @@
 /*
 
-Copyright (C) 2000  Paul Wilkins
+Copyright (C) 2002  Paul Wilkins
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
@@ -42,6 +42,10 @@ FuncInfo invisible1[] = {
       baseCmdCB, (void *)OCTAL },
    { "Bin", "bin", "Binary display mode.",
       baseCmdCB, (void *)BINARY },
+   { "Db10", "db10", "Convert to dB (Power).",
+      genericButtonCB, (void *)Db10Stack },
+   { "Db20", "db20", "Convert to dB (Voltage).",
+      genericButtonCB, (void *)Db20Stack },
    { "Rip", "rip", "Resistors in parallel.",
       genericButtonCB, (void *)RipStack },
    { "Cplx", "cplx", "Create a complex number.", 
@@ -133,7 +137,7 @@ struct RowInfo rowinf[] = {
    { 8, 8, num456 },
    { 8, 8, num123 },
    { 8, 8, num0 },
-   { 12, 0, invisible1 }
+   { 14, 0, invisible1 }
 };
 
 
