@@ -1,6 +1,6 @@
 /*
 
-Copyright (C) 2000  Paul Wilkins
+Copyright (C) 2002  Paul Wilkins
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
@@ -314,6 +314,45 @@ void SqrtStack(){
    }
 }
 
+void Db10Stack(){
+   Number *n1, *n2;
+
+   finishEditor();
+
+   if(checkArgs("db10", 1)) return;
+   SaveStackState(1);
+
+   n1 = Pop();
+
+   n2 = dbNumber(n1, 10.0);
+   if(n2){
+      Push(n2); freeNumber(n1);
+      UndoStackState(1);
+   } else {
+      Push(n1);
+      CancelStackState();
+   }
+}
+
+void Db20Stack(){
+   Number *n1, *n2;
+
+   finishEditor();
+
+   if(checkArgs("db20", 1)) return;
+   SaveStackState(1);
+
+   n1 = Pop();
+
+   n2 = dbNumber(n1, 20.0);
+   if(n2){
+      Push(n2); freeNumber(n1);
+      UndoStackState(1);
+   } else {
+      Push(n1);
+      CancelStackState();
+   }
+}
 
 void RipStack(){
    Number *n1, *n2, *n3;
