@@ -1,6 +1,6 @@
 /*
 
-Copyright (C) 2000  Paul Wilkins
+Copyright (C) 2002  Paul Wilkins
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
@@ -319,9 +319,9 @@ Number * sinNumber(Number *a){
       case REAL:
          c->type = REAL;
         
-	 r1 = fromRadixReal(a->data);
-	 c->data = sinReal(r1);
-	 freeReal(r1);
+         r1 = fromRadixReal(a->data);
+         c->data = sinReal(r1);
+         freeReal(r1);
 
          break;
       case COMPLEX:
@@ -351,9 +351,9 @@ Number * cosNumber(Number *a){
       case REAL:
          c->type = REAL;
 
-	 r1 = fromRadixReal(a->data);
-	 c->data = cosReal(r1);
-	 freeReal(r1);
+         r1 = fromRadixReal(a->data);
+         c->data = cosReal(r1);
+         freeReal(r1);
 
          break;
       case COMPLEX:
@@ -383,9 +383,9 @@ Number * tanNumber(Number *a){
       case REAL:
          c->type = REAL;
 
-	 r1 = fromRadixReal(a->data);
-	 c->data = tanReal(r1);
-	 freeReal(r1);
+         r1 = fromRadixReal(a->data);
+         c->data = tanReal(r1);
+         freeReal(r1);
 
          break;
       case COMPLEX:
@@ -424,9 +424,9 @@ Number * asinNumber(Number *a){
          } else {
             c->type = REAL;
 
-	    r1 = asinReal(a->data);
-	    c->data = toRadixReal(r1);
-	    freeReal(r1);
+            r1 = asinReal(a->data);
+            c->data = toRadixReal(r1);
+            freeReal(r1);
          }
          break;
       case COMPLEX:
@@ -465,9 +465,9 @@ Number * acosNumber(Number *a){
          } else {
             c->type = REAL;
 
-	    r1 = acosReal(a->data);
-	    c->data = toRadixReal(r1);
-	    freeReal(r1);
+            r1 = acosReal(a->data);
+            c->data = toRadixReal(r1);
+            freeReal(r1);
          }
          break;
       case COMPLEX:
@@ -496,9 +496,9 @@ Number * atanNumber(Number *a){
    switch(a->type){
       case REAL:
          c->type = REAL;
-	 r1 = atanReal(a->data);
-	 c->data = toRadixReal(r1);
-	 freeReal(r1);
+         r1 = atanReal(a->data);
+         c->data = toRadixReal(r1);
+         freeReal(r1);
          break;
       case COMPLEX:
          c->type = COMPLEX;
@@ -605,39 +605,70 @@ Number * ripNumber(Number *a, Number *b){
    switch(a->type){
       case REAL:
       case COMPLEX:
-	 switch(b->type){
-	    case REAL:
-	    case COMPLEX:
-	       num = mulNumber(a,b);
-	       den = addNumber(a,b);
-	       c = divNumber(num,den);
+         switch(b->type){
+            case REAL:
+            case COMPLEX:
+               num = mulNumber(a,b);
+               den = addNumber(a,b);
+               c = divNumber(num,den);
                freeNumber(num);
                freeNumber(den);
-	       break;
-	    case MATRIX:
-	      invalidTyprError("rip");
-	      return NULL;
-	      break;
-	    default:
-	      fprintf(stderr, "Error: Unknown number type\n");
-	      exit(0);
-	      break;
-	 }
-	 break;
+               break;
+            case MATRIX:
+              invalidTyprError("rip");
+              return NULL;
+              break;
+            default:
+              fprintf(stderr, "Error: Unknown number type\n");
+              exit(0);
+              break;
+         }
+         break;
       case MATRIX:
-	invalidTyprError("rip");
-	return NULL;
-	break;
+        invalidTyprError("rip");
+        return NULL;
+        break;
       default:
-	fprintf(stderr, "Error: Unknown number type\n");
-	exit(0);
-	break;
+        fprintf(stderr, "Error: Unknown number type\n");
+        exit(0);
+        break;
    }
 
    return c;
 }
 
 
+Number * dbNumber(Number *a, double sf){
+   Real *r1;
+   Number *c;
+   Number *n1, *n2;
+
+   if(a == NULL) 
+      { fprintf(stderr, "dbNumber(NULL)\n"); exit(0); }
+
+   switch(a->type){
+      case REAL:
+      case COMPLEX:
+         n1 = logNumber(a);
+         n2 = setNumberReal(newNumber(), setRealDouble((r1=newReal()), sf));
+         c = mulNumber(n1, n2);
+         freeNumber(n1);
+         freeNumber(n2);
+         freeReal(r1);
+         break;
+      case MATRIX:
+        invalidTyprError("db");
+        return NULL;
+        break;
+      default:
+        fprintf(stderr, "Error: Unknown number type\n");
+        exit(0);
+        break;
+   }
+
+   return c;
+}
+
 Number * mulNumber(Number *a, Number *b){
    Number *c = newNumber();
 
